<?php
/**
 * @file
 * Base struct definitions with default values to prepopulate forms and objects.
 *
 * http://lunar.lyris.com/help/lm_api/11.1/
 */

/**
 * Implements hook_struct_data().
 */
function lyris_struct_data() {
  $fields['ListStruct'] = array(
    // Vertical Tab Groups
    'vertical_tabs' => array(
      '#type' => 'vertical_tabs',
      '#groups' => array(
        'mailings'     => array('#weight' => 1, '#title' => t('Basic Mailing Settings'), '#description' => t('These values may be overridden by each piece of content then also per content mailing.')),
        'more_mailings' => array('#weight' => 2, '#title' => t('Advanced Mailing Settings')),
        'admin'        => array('#weight' => 3, '#title' => t('Administrative Settings')),
        'posting'      => array('#weight' => 4, '#title' => t('Posting')),
        'subscription' => array('#weight' => 5, '#title' => t('Subscription Settings'), '#description' => t('To enable subscription features such as the member subscription block and views integration, the Lyris Members module must be enabled.')),
        'recency'      => array('#weight' => 6, '#title' => t('Recency Settings')),
        'scripting'    => array('#weight' => 7, '#title' => t('Scripting')),
        'maintenance'  => array('#weight' => 8, '#title' => t('Basic Settings & Maintenance')),
        'reporting'    => array('#weight' => 9, '#title' => t('Reporting & Logging')),
      ),
      '#permanent' => TRUE,
    ),

    'Additional' => array(
      '#type' => 'textfield',
      '#title' => t('Additional Information'),
      '#description' => t('Additional information about this list (not used by ListManager).'),
      '#default_value' => NULL,
      '#maxlength' => 255,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
    'AddListNameToSubject' => array(
      '#type' => 'checkbox',
      '#title' => t('Add List Name to Subject'),
      '#description' => t('If true, adds the list\'s name to the "Subject:" header.  It is recommended to leave this off and use tokens instead to insert the human-readable name.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 35,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'Admin' => array(
      '#type' => 'textfield',
      '#title' => t('Admin Name'),
      '#description' => t('Administrator responsible for this list.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#hidden' => TRUE,
      '#schema' => array(
        'type' => 'varchar',
        'length' => '64',
      ),
      '#defaultable' => FALSE,
    ),
    'AllowCrossPosting' => array(
      '#type' => 'checkbox',
      '#title' => t('Allow Cross Posting'),
      '#description' => t('If true, this list should accept cross-posted messages (identical messages sent to multiple lists).'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'AllowDuplicatePosts' => array(
      '#type' => 'checkbox',
      '#title' => t('Allow Duplicate Posts'),
      '#description' => t('If true, this list should accept duplicate messages.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'AllowInfo' => array(
      '#type' => 'checkbox',
      '#title' => t('Allow Info'),
      '#description' => t('If true, this list should allow non-members to read information about it.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'AnyoneCanPost' => array(
      '#type' => 'checkbox',
      '#title' => t('Anyone Can Post'),
      '#description' => t('If true, this list should allow anyone to post; if false, it requires those who post to be members.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'ApproveNum' => array(
      '#type' => 'textfield',
      '#title' => t('Approval Number'),
      '#description' => t('The number of approvals required of new members before they may post to the list without moderation.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#size' => 10,
      '#maxlength' => 5,
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'ArchiveDays' => array(
      '#type' => 'textfield',
      '#title' => t('Archive Days'),
      '#description' => t('The number of days archived messages are kept.'),
      '#default_value' => 90,
      '#size' => 10,
      '#maxlength' => 5,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'ArchiveNum' => array(
      '#type' => 'textfield',
      '#title' => t('Archive Number'),
      '#description' => t('The number of archived messages kept'),
      '#default_value' => 200,
      '#size' => 10,
      '#maxlength' => 6,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'AutoReleaseHour' => array(
      '#type' => 'select',
      '#title' => t('Auto Release Hour'),
      '#description' => t('The time of day messages should be automatically approved and released.'),
      '#options' => drupal_map_assoc(range(0, 24)),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 2,
        'unsigned' => TRUE,
      ),
    ),
    'BlankSubjectOk' => array(
      '#type' => 'checkbox',
      '#title' => t('Blank Subject OK'),
      '#description' => t('If true, the list should permit messages with blank "Subject:" headers.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 40,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'Child' => array(
      '#type' => 'checkbox',
      '#title' => t('Child'),
      '#description' => t('If true, this list should accept postings from other lists.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'CleanAuto' => array(
      '#type' => 'checkbox',
      '#title' => t('Auto Hold'),
      '#description' => t('If true, this list should automatically put members who bounce too much mail on hold.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'CleanNotif' => array(
      '#type' => 'textfield',
      '#title' => t('Hold Notification Days'),
      '#description' => t('The length of time (days) a "held" member will be notified.'),
      '#default_value' => 0,
      '#size' => 10,
      '#maxlength' => 3,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'Comment' => array(
      '#type' => 'textfield',
      '#title' => t('Comment'),
      '#description' => t('Additional information about this list (not used by ListManager).'),
      '#default_value' => t('This list is managed by the Drupal site @name.', array('@name' => variable_get('site_name'))),
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
        'not null' => FALSE,
      ),
    ),
    'CommentsID' => array(
      '#type' => 'textfield',
      '#title' => t('Comments ID'),
      '#description' => t('Comment about this list (links to a document).'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'unsigned' => TRUE,
        'not null' => FALSE,
      ),
      '#element_validate' => array('_lyris_element_validate_integer'),
    ),
    'ConfirmSubscribes' => array(
      '#type' => 'checkbox',
      '#title' => t('Confirm Subscribes'),
      '#description' => t('Whether this list should confirm new subscriptions.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'ConfirmUnsubscribes' => array(
      '#type' => 'select',
      '#title' => t('Confirm Unsubscribes'),
      '#description' => t('Whether this list should confirm unsubscribes.'),
      '#options' => lyris_enum('ConfirmUnsubEnum'),
      '#default_value' => 2,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'DateCreated' => array(
      '#type' => 'item',
      '#title' => t('Date Created'),
      '#description' => t('The date and time this list was created.'),
      '#markup' => t('Set per list.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 10,
        'unsigned' => TRUE,
      ),
      '#defaultable' => FALSE,
    ),
    'DefaultFrom' => array(
      '#type' => 'textfield',
      '#title' => t('Default "From:" Header'),
      '#description' => t('The default \'From\' header for each new content.  May be overridden in each content.') . '<br />' . t('Format: <strong>name@example.com</strong> or <strong>"John Doe" &lt;johndoe@example.com&gt;</strong>'),
      '#maxlength' => 128,
      '#default_value' => '"[site:name]" <[site:mail]>',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailings',
      '#weight' => 10,
      '#schema' => array(
        'type' => 'text',
        'not null' => FALSE,
      ),
    ),
    'DefaultSubject' => array(
      '#type' => 'textfield',
      '#title' => t('Default "Subject:"'),
      '#description' => t('The default subject for each new content mailed.  May be overriden in each content.'),
      '#default_value' => '[[lyris_list:name]] [lyris_content:title]',
      '#maxlength' => 128,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailings',
      '#weight' => 30,
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'DefaultTo' => array(
      '#type' => 'textfield',
      '#title' => t('Default "To:" Header'),
      '#description' => t('The default \'To\' header for all new content.  May be overridden in each content.') . '<br />' . t('Use the token "[lyris_mailing:email]" to show each member\'s email address.'),
      '#maxlength' => 128,
      '#default_value' => '[lyris_mailing:email]',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailings',
      '#weight' => 0,
      '#schema' => array(
        'type' => 'text',
        'not null' => FALSE,
      ),
    ),
    'DeliveryReports' => array(
      '#type' => 'select',
      '#title' => t('Delivery Reports'),
      '#description' => t('What delivery reports should be sent to administrators.'),
      '#options' => lyris_enum('DeliveryReportEnum'),
      '#default_value' => 8,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'reporting',
      '#schema' => array(
        'type' => 'int',
        'length' => 2,
        'unsigned' => TRUE,
      ),
    ),
    'DescLongDocID' => array(
      '#type' => 'textfield',
      '#title' => t('Long Description Doc ID'),
      '#description' => t('Long description of this list (links to a document).'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'not null' => FALSE,
      ),
      '#element_validate' => array('_lyris_element_validate_integer'),
    ),
    'DetectHtmlByDefault' => array(
      '#type' => 'checkbox',
      '#title' => t('Auto-Detect HTML'),
      '#description' => t('If true, this list should detect HTML capability by default.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 80,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'DetectOpenByDefault' => array(
      '#type' => 'checkbox',
      '#title' => t('Auto-Detect Opens'),
      '#description' => t('If true, this list should detect HTML opens by default.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 85,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'DigestFooter' => array(
      '#type' => 'textarea',
      '#title' => t('The Digest Footer'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
    'DigestHeader' => array(
      '#type' => 'textarea',
      '#title' => t('The Digest Header'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
    'Disabled' => array(
      '#type' => 'checkbox',
      '#title' => t('Disabled'),
      '#description' => t('If true, this list is disabled.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'DontRewriteMessageIDHeader' => array(
      '#type' => 'checkbox',
      '#title' => t('Don\'t Rewrite Message ID Header'),
      '#description' => t('If true, ListManager will not rewrite the Message-ID, but instead leave it alone, and use X-Lyris-Message-ID.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 55,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'EnableScripting' => array(
      '#type' => 'select',
      '#title' => t('Enable Scripting'),
      '#description' => t('What level of scripting the list allows.'),
      '#options' => lyris_enum('EnableScriptingEnum'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'int',
        'unsigned' => TRUE,
        'length' => 1,
      ),
    ),
    'ErrHold' => array(
      '#type' => 'textfield',
      '#title' => t('Bounces to Hold'),
      '#description' => t('How many bounces before a member is put on hold.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 3,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'From' => array(
      '#type' => 'textfield',
      '#title' => t('From'),
      '#description' => t('If set, specifies the "From:" header of every message send on this list.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailings',
      '#weight' => 15,
      '#schema' => array(
        'type' => 'text',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'HeaderRemove' => array(
      '#type' => 'textarea',
      '#title' => t('Remove Headers'),
      '#description' => t('Remove headers from mailings.  One per line.') . '<br />' . t('<strong>Sender</strong> - Removes the "Sent On Behalf Of" part of the header.'),
      '#rows' => 3,
      '#default_value' => 'Sender',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 45,
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'KeepOutmailPostings' => array(
      '#type' => 'textfield',
      '#title' => t('Keep Mailings'),
      '#description' => t('How long mailings sent to the list should be kept.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 3,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'Keywords' => array(
      '#type' => 'textfield',
      '#title' => t('Keywords'),
      '#description' => t('Keywords which describe this list.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'ListID' => array(
      '#type' => 'item',
      '#title' => t('List ID'),
      '#description' => t('The unique identifier for this list.'),
      '#markup' => t('Generated by Lyris'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#hidden' => TRUE,
      '#schema' => array(
        'type' => 'int',
        'not null' => TRUE,
        'unsigned' => TRUE,
      ),
      '#group' => 'admin',
      '#defaultable' => FALSE,
    ),
    'ListName' => array(
      '#type' => 'machine_name',
      '#title' => t('Lyris List Name'),
      '#default_value' => NULL,
      '#default_description' => t('List creators and editors must have \'Edit\' permission.'),
      '#disabled' => FALSE,
      '#machine_name' => array(
        'source' => array('title'),
        'label' => t('Lyris List Name'),
      ),
      '#attributes' => array('class' => array('lyris-validate-name'), 'list-name' => '1'),
      '#element_validate' => array('lyris_list_name_unique_validate'),
      //'#field_prefix' => lyris_list_prefix(),
      '#schema' => array(
        'type' => 'varchar',
        'length' => '255',
        'not null' => TRUE,
      ),
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => -98,
      '#permanent' => TRUE,
      '#defaultable' => FALSE,
    ),
    'MakePostsAnonymous' => array(
      '#type' => 'checkbox',
      '#title' => t('Make Posts Anonymous'),
      '#description' => t('If true, posts to this list will be anonymous.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => -5,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'MaxMembers' => array(
      '#type' => 'textfield',
      '#title' => t('Max Members'),
      '#description' => t('The maximum number of members this list is allowed. 0 for no limit.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'MaxMessageSize' => array(
      '#type' => 'textfield',
      '#title' => t('Max Message Size'),
      '#description' => t('The maximum size, in bytes, non-administrators may post to the list.'),
      '#size' => 10,
      '#maxlength' => 8,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'MaxMessNum' => array(
      '#type' => 'textfield',
      '#title' => t('Max Mailings per Day'),
      '#description' => t('The maximum number of messages that may be sent through the list in a 24-hour period.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'MaxPostsPerUser' => array(
      '#type' => 'textfield',
      '#title' => t('Max Posts per User'),
      '#description' => t('The maximum number of posts a single person may post to the list'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'MaxQuoting' => array(
      '#type' => 'textfield',
      '#title' => t('Max Quoted Lines'),
      '#desc' => t('The maximum number of contiguous lines that may be quoted at once in a single message.'),
      '#size' => 10,
      '#maxlength' => 5,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'MemberListSecurity' => array(
      '#type' => 'select',
      '#title' => t('Member List Security'),
      '#description' => t('Who may access the list of members.'),
      '#options' => lyris_enum('MemberListSecurityEnum'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'MergeCapOverride' => array(
      '#type' => 'select',
      '#title' => t('Override Server Scripting Levels'),
      '#description' => t('Whether this list should override the server scripting levels.'),
      '#options' => lyris_enum('MergeCapOverrideEnum'),
      '#default_value' => 3,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'MessageHeader' => array(
      '#type' => 'textarea',
      '#title' => t('Default Header'),
      '#rows' => 3,
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 65,
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
    'MessageFooter' => array(
      '#type' => 'textarea',
      '#title' => t('Default Footer'),
      '#rows' => 3,
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 70,
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
    'Moderated' => array(
      '#type' => 'select',
      '#title' => t('Moderation Level'),
      '#description' => t('What level of moderation this list requires.'),
      '#options' => lyris_enum('ModeratedEnum'),
      '#default_value' => 'no',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 6,
      ),
    ),
    'ModifyHeaderDate' => array(
      '#type' => 'checkbox',
      '#title' => t('Modify Header Date'),
      '#description' => t('Whether the "Date:" header should automatically be rewritten to be the date and time a message is approved.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'MRIVisibility' => array(
      '#type' => 'select',
      '#title' => t('Discussion Forum Interface'),
      '#description' => t('Whether the Discussion Forum Interface for this list should be (v)isible, (h)idden or (i)nvisible.'),
      '#options' => lyris_enum('MRIVisibilityEnum'),
      '#default_value' => 'I',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 1,
      ),
    ),
    'NameRequired' => array(
      '#type' => 'select',
      '#title' => t('Subscriber Name Required'),
      '#description' => t('Whether the subscriber must provide a name when joining.'),
      '#options' => lyris_enum('NameRequiredEnum'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NewSubscriberSecurity' => array(
      '#type' => 'select',
      '#title' => t('New Subscriber Security'),
      '#description' => t('What security controls who may join the list.'),
      '#options' => lyris_enum('NewSubscriberSecurityEnum'),
      '#default_value' => 'open',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 8,
      ),
    ),
    'NoArchive' => array(
      '#type' => 'checkbox',
      '#title' => t('No Archive'),
      '#description' => t('If true, this list maintains a message archive.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NoBodyOk' => array(
      '#type' => 'checkbox',
      '#title' => t('Allow Empty Body'),
      '#description' => t('If true, messages posted to this list may be blank.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 75,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NoEmail' => array(
      '#type' => 'checkbox',
      '#title' => t('Prohibit Posting via E-Mail'),
      '#description' => t('If true, this list rejects messages posted via email, and requires postings through the ListManager web interface.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NoEmailSubscriptions' => array(
      '#type' => 'checkbox',
      '#title' => t('Prohibit Subscribing via E-mail'),
      '#description' => t('If true, this list prohibits subscriptions via email, and requires them through the ListManager web interface.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NoListHeader' => array(
      '#type' => 'checkbox',
      '#title' => t('No Help Headers'),
      '#description' => t('If true, the list-help headers should not be included.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 60,
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NoNNTP' => array(
      '#type' => 'checkbox',
      '#title' => t('No NNTP'),
      '#description' => t('If true, the list will not be accessible via NNTP.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NoSearch' => array(
      '#type' => 'checkbox',
      '#title' => t('Unsearchable'),
      '#description' => t('If true, the list\'s archives, if available, will not be searchable.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'reporting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'NotifyHeldInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Held Notification Fequency'),
      '#description' => t('How frequently held members should be notified.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'OnlyAllowAdminSend' => array(
      '#type' => 'checkbox',
      '#title' => t('Only Admins May Send'),
      '#description' => t('If true the list will only allow administrators to send.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'PasswordRequired' => array(
      '#type' => 'checkbox',
      '#title' => t('Password Required'),
      '#description' => t('Whether a password is required when joining.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'PostPassword' => array(
      '#type' => 'select',
      '#title' => t('Post Password'),
      '#description' => t('Whether a member\'s password must be included in the message in order to be posted.'),
      '#options' => lyris_enum('PostPasswordEnum'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'PrivApprov' => array(
      '#type' => 'textfield',
      '#title' => t('Private List Approval'),
      '#description' => t('Sets rules for automatically approving applications to a private list.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'varchar',
      ),
    ),
    'PurgeExpiredInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Purge Expired Interval'),
      '#description' => t('How long expired members should be kept in the database before being purged, in days.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'PurgeHeldInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Purge Held Interval'),
      '#description' => t('How long held members should be kept in the database before being purged, in days.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'PurgeReferredInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Purge Referred Interval'),
      '#description' => t('How long referred members should be kept in the database before being purged, in days.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'PurgeUnapprovedInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Purge Unapproved Interval'),
      '#description' => t('How long unapproved members should be kept in the database before being purged, in days.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'PurgeUnconfirmedInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Purge Unconfirmed Interval'),
      '#description' => t('How long unconfirmed members should be kept in the database before being purged, in days.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'PurgeUnsubInterval' => array(
      '#type' => 'textfield',
      '#title' => t('Purge Unsubscribed Interval'),
      '#description' => t('How long unsubscribed members should be kept in the database before being purged, in days.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'RecencyDayCount' => array(
      '#type' => 'textfield',
      '#title' => t('Recency Day Count'),
      '#description' => t('How many days to check for recent mailings.'),
      '#size' => 10,
      '#maxlength' => 3,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'RecencyEmailEnabled' => array(
      '#type' => 'checkbox',
      '#title' => t('Recency E-mail Enabled'),
      '#description' => t('If true, recency checking/purging is enabled.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'RecencyMailCount' => array(
      '#type' => 'textfield',
      '#title' => t('Recency Mail Count'),
      '#description' => t('The number of mailings that should trigger recency limits.'),
      '#size' => 10,
      '#maxlength' => 5,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'RecencyOperator' => array(
      '#type' => 'select',
      '#title' => t('Recency Operator'),
      '#description' => t('When checking for recency, should the number of mailings be (m)ore than, (e)qual to or (l)ess than the number in RecencyMailCount.'),
      '#options' => lyris_enum('RecencyOperatorEnum'),
      '#default_value' => 'm',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 1,
      ),
    ),
    'RecencySequentialEnabled' => array(
      '#type' => 'checkbox',
      '#title' => t('Recency Sequntial Enabled'),
      '#description' => t('If true, recency limits should be applied to sequential mailings.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'RecencyTriggeredEnabled' => array(
      '#type' => 'checkbox',
      '#title' => t('Recency Triggered Enabled'),
      '#description' => t('If true, recency limits should be applied to triggered mailings.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'RecencyWebEnabled' => array(
      '#type' => 'checkbox',
      '#title' => t('Recency Web Enabled'),
      '#description' => t('If true, recency limits should be applied to web mailings'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'recency',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'RecipientLoggingLevel' => array(
      '#type' => 'select',
      '#title' => t('Recipient Logging Level'),
      '#description' => t('What level of delivery logging should there be? (N)o logging, non-SMTP errors (m), all (e)rrors, errors and successes (f).'),
      '#options' => lyris_enum('LoggingLevelEnum'),
      '#default_value' => 'E',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'reporting',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 1,
      ),
    ),
    'ReferralsPerDay' => array(
      '#type' => 'textfield',
      '#title' => t('Referrals Per Day'),
      '#description' => t('The number of referrals allowed per member per day.'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'ReleasePending' => array(
      '#type' => 'textfield',
      '#title' => t('Pending Release Timeout'),
      '#description' => t('The length of time unapproved messages should be kept before being sent automatically.'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#group' => 'maintenance',
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'RemoveDuplicateCrossPostings' => array(
      '#type' => 'checkbox',
      '#title' => t('Remove Duplicate Cross Postings'),
      '#description' => t('If true, if a list allows cross-postings, it should clean out duplicate recipients so that members of multiple lists only receive one copy of a message.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'ReplyTo' => array(
      '#type' => 'textfield',
      '#title' => t('The "Reply-To:" Header'),
      '#description' => t('The value of the \'Reply-To\' header for each mailing.  May not be overridden.') . '<br \>' . t('Format: <strong>just.the@email.com</strong> or use <strong>[site:mail]</strong> to use your site\'s e-mail address.'),
      '#default_value' => '[site:mail]',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailings',
      '#weight' => 25,
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'RunProgAfterPosting' => array(
      '#type' => 'textfield',
      '#title' => t('Run Program After Posting'),
      '#description' => t('Program to execute after posting.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'RunProgAfterSub' => array(
      '#type' => 'textfield',
      '#title' => t('Run Program After Subscribing'),
      '#description' => t('Program to execute after subscribing.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'RunProgAfterUnsub' => array(
      '#type' => 'textfield',
      '#title' => t('Run Program After Unsubscribing'),
      '#description' => t('Program to execute after unsubscribing.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'RunProgBeforePosting' => array(
      '#type' =>'textfield',
      '#title' => t('Run Program Before Posting'),
      '#description' => t('Program to execute before posting a message.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'RunProgBeforeSub' => array(
      '#type' => 'textfield',
      '#title' => t('Run Program Before Subscribing'),
      '#description' => t('Program to execute before processing a subscribe.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'RunProgBeforeUnsub' => array(
      '#type' => 'textfield',
      '#title' => t('Run Program Before Unsubscribing'),
      '#description' => t('Program to execute before processing an unsubscribe.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'ScriptingLevel' => array(
      '#type' => 'select',
      '#title' => t('Scripting Level'),
      '#description' => t('What level of scripting should this list allow.'),
      '#options' => lyris_enum('ScriptingLevelEnum'),
      '#default_value' => 2,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'scripting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'ShortDescription' => array(
      '#type' => 'textfield',
      '#title' => t('List Description'),
      '#description' => t('A short description of this list.'),
      '#default_value' => t('Describe this list.'),
      '#required' => TRUE,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#schema' => array(
        'type' => 'text',
        'not null' => FALSE,
      ),
      //'#group' => 'admin',
    ),
    'SimpleSub' => array(
      '#type' => 'checkbox',
      '#title' => t('Simple Subscriptions'),
      '#description' => t('If true, this list should only allow name, email address, or allow members to set other options (such as noack, norepro).'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'SMTPFrom' => array(
      '#type' => 'textfield',
      '#title' => t('The SMTP "MAIL FROM:" Header'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 20,
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'SMTPHeaders' => array(
      '#type' => 'textarea',
      '#title' => t('SMTP Headers'),
      '#description' => t('Text that should be included in the SMTP header of every message.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'more_mailings',
      '#weight' => 50,
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
    ),
    'SponsOrgID' => array(
      '#type' => 'textfield',
      '#title' => t('Sponsor Org ID'),
      '#description' => t('Organization that is sponsoring this list (link to document, type is organization).'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'varchar',
      ),
    ),
    'SubscribePassword' => array(
      '#type' => 'textfield',
      '#title' => t('List Password'),
      '#description' => t('If this list is password protected for new subscribers, what is the password?'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'subscription',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 64,
      ),
    ),
    'SubscriptionReports' => array(
      '#type' => 'select',
      '#title' => t('Subscription Reports'),
      '#description' => t('What subscription reports should be emailed to list administrators?'),
      '#options' => lyris_enum('SubscriptionReportEnum'),
      '#multiple' => TRUE,
      '#size' => 10,
      '#default_value' => 'none',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'reporting',
      '#schema' => array(
        'type' => 'text',
        'not null' => FALSE,
      ),
    ),
    'To' => array(
      '#type' => 'textfield',
      '#title' => t('To'),
      '#description' => t('The value of the \'To\' header for each mailing.  Use the token "[lyris_mailing:email]" to user each member\'s e-mail address.'),
      '#default_value' => '[lyris_mailing:email]',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailings',
      '#weight' => 5,
      '#schema' => array(
        'type' => 'text',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'Topic' => array(
      '#type' => 'textfield',
      '#title' => t('Topic'),
      '#description' => t('The category the mailing list belongs to.'),
      '#default_value' => 'main',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#required' => TRUE,
      '#schema' => array(
        'type' => 'varchar',
        'length' => 128,
      ),
    ),
    'Visitors' => array(
      '#type' => 'checkbox',
      '#title' => t('Visitors'),
      '#description' => t('If true, the list should allow non-members to see messages in the Discussion Forum Interface.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'posting',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
  );

  /**
   * Content Struct
   */
  $fields['ContentStruct'] = array(
    // Vertical Tab Groups
    'vertical_tabs' => array(
      '#type' => 'vertical_tabs',
      '#groups' => array(
        'mailing' => array('#weight' => 1, '#title' => t('Mailing Settings')),
        'content' => array('#weight' => 2, '#title' => t('Content Settings'), '#description' => t('The content fields will be populated using data from the Body field.  Unless the Body field has been removed, it is recommended to leave these fields hidden.')),
        'admin'   => array('#weight' => 3, '#title' => t('Administrative Settings')),
      ),
      '#permanent' => TRUE,
    ),
    'ContentID' => array(
      '#type' => 'textfield',
      '#title' => t('Content ID'),
      '#description' => t('Unique ID in Docs_ table.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'not null' => TRUE,
      ),
      '#defaultable' => FALSE,
    ),
    'DateCreated' => array(
      '#type' => 'textfield',
      '#title' => t('Date Created'),
      '#description' => t('Date content was created.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 10,
        'unsigned' => TRUE,
      ),
      '#defaultable' => FALSE,
    ),
    'Description' => array(
      '#type' => 'textfield',
      '#title' => t('Content Description'),
      '#description' => t('The administrative description of this content.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => -9,
      '#required' => TRUE,
      '#permission' => array('hide' => FALSE, 'read' => FALSE),
      '#schema' => array(
        'type' => 'text',
      ),
    ),
    'DocParts' => array(
      '#title' => t('Content'),
      '#type' => 'fieldset',
      '#group' => 'content',
      '#filter' => array(
        'local' => TRUE,
        'lyris' => FALSE,
      ),
      '#struct' => array(
        '#name' => 'DocPart',
        '#multiple' => TRUE,
      ),
    ),
    'DocType' => array(
      '#type' => 'select',
      '#title' => t('Document Type'),
      '#options' => lyris_enum('DocTypeEnum'),
      '#default_value' => 'CONTENTv2',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 9,
      ),
    ),
    'HeaderFrom' => array(
      '#type' => 'textfield',
      '#title' => t('From'),
      '#description' => t('The \'From\' header for all mailings sent from this list.') . '<br />' . t('Format: <strong>name@example.com</strong> or <strong>"John Doe" &lt;johndoe@example.com&gt;</strong>'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailing',
      '#schema' => array(
        'type' => 'text',
      ),
      '#overrides' => array(
        'defaults_form' => array('#description' => t('Default value is inherited from the List settings.  May be overridden in each content.')),
      ),
      '#defaultable' => FALSE,
      '#weight' => 1,
    ),
    'HeaderTo' => array(
      '#type' => 'textfield',
      '#title' => t('\'To\' Header'),
      '#description' => t('The \'To\' header for all mailings sent from this list.') . '<br /><strong>' . t('Does not affect who receives the e-mail, just whose name is in the \'To\' section.') . '</strong><br />' . t('Format: <strong>name@example.com</strong> or <strong>"John Doe" &lt;johndoe@example.com&gt;</strong> or use the token "[lyris_mailing:email]" to show each member\'s e-mail address.'),
      '#default_value' => '[lyris_mailing:email]',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailing',
      '#schema' => array(
        'type' => 'text',
      ),
      '#overrides' => array(
        'defaults_form' => array('#description' => t('Default value is inherited from the List settings.  May be overriden in each content.')),
      ),
      '#defaultable' => FALSE,
      '#weight' => 0,
    ),
    'IsReadOnly' => array(
      '#type' => 'checkbox',
      '#title' => t('Read-Only'),
      '#description' => t('If true, web interface will not let user change this document in the web interface.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'IsTemplate' => array(
      '#type' => 'checkbox',
      '#title' => t('Template'),
      '#description' => t('If true, this content is a template.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    // ListName is not actually used in 1.5.2a but we need it in order to bundle
    // content.
    'ListName' => array(
      '#type' => 'textfield',
      '#title' => t('List Name'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 128,
      ),
      '#defaultable' => FALSE,
    ),
    'NativeTitle' => array(
      '#type' => 'textfield',
      '#title' => t('E-Mail Subject'),
      '#description' => t('The default subject for each mailing.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'mailing',
      '#required' => TRUE,
      '#overrides' => array(
        'defaults_form' => array('#description' => t('Default value is inherited from the List settings.')),
      ),
      '#schema' => array(
        'type' => 'text',
      ),
      '#defaultable' => FALSE,
    ),
    'SiteName' => array(
      '#type' => 'textfield',
      '#title' => t('Topic'),
      '#description' => t('A topic or site name to post into.'),
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 128,
      ),
    ),
    'Title' => array(
      '#type' => 'textfield',
      '#title' => t('Content Title'),
      '#description' => t('Administrative title of the content for Lyris.  Must be unique.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => -10,
      '#required' => TRUE,
      '#schema' => array(
        'type' => 'text',
      ),
      '#permission' => array('hide' => FALSE, 'read' => FALSE),
    ),
  );

  $fields['DocPart'] = array(
    'Body' => array(
      '#type' => 'textarea',
      '#title' => t('Body'),
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'content',
      '#filter' => array(
        'extra_fields' => FALSE,
      ),
      /*'#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),*/
    ),
    'MimePartName' => array(
      '#type' => 'select',
      '#title' => t('Format'),
      '#options' => array(
        'text' => t('Plain Text'),
        'html' => t('HTML'),
      ),
      '#default_value' => 'html',
      '#api' => array('10', '11', '12'),
      '#group' => 'content',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 4,
      ),
    ),
    'CharSetID' => array(
      '#type' => 'textfield',
      '#title' => t('Character Set'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 1,
      '#api' => array('10', '11', '12'),
      '#group' => 'content',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'Encoding' => array(
      '#type' => 'select',
      '#title' => t('Encoding'),
      '#options' => lyris_enum('MailSectionEncodingEnum'),
      '#default_value' => '8bit',
      '#api' => array('10', '11', '12'),
      '#group' => 'content',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 16,
      ),
    ),
  );

  /**
   * Mailing Struct
   *
   * We're filtering out SimpleMailingStruct fields as those will be populated
   * from the SimpleMailingStruct received from ImportContent.
   */
  $fields['MailingStruct'] = array(
    // Vertical Tab Groups
    'vertical_tabs' => array(
      '#type' => 'vertical_tabs',
      '#groups' => array(
        'basic'    => array('#weight' => 1, '#title' => t('Basic Settings'), '#description' => t('Most basic settings are inherrited from the content.')),
        'advanced' => array('#weight' => 2, '#title' => t('Advanced Settings')),
        'admin'    => array('#weight' => 3, '#title' => t('Administrative Settings')),
      ),
      '#permanent' => TRUE,
    ),
    'AdditionalHeaders' => array(
      '#type' => 'textarea',
      '#title' => t('Additional Headers'),
      '#description' => t('Any addtional headers (e.g., X-type headers).'),
      '#default_value' => NULL,
      '#api' => array('10'),
      '#group' => 'advanced',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'Attachments' => array(
      '#type' => 'textarea',
      '#title' => t('Attachments'),
      '#description' => t('Any attachments.'),
      '#default_value' => NULL,
      '#api' => array('10'),
      '#group' => 'advanced',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'BypassModeration' => array(
      '#type' => 'checkbox',
      '#title' => t('Bypass Moderation'),
      '#description' => t('If true, the mailing may bypass moderation.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'Campaign' => array(
      '#type' => 'textfield',
      '#title' => t('Campaign'),
      '#description' => t('What campaign the mailing should belong to.'),
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'advanced',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 128,
      ),
    ),
    'CharSetID' => array(
      '#type' => 'textfield',
      '#title' => t('Character Set'),
      '#description' => t('The ID of the charset for this mailing'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 1,
      '#api' => array('10', '11', '12'),
      '#group' => 'admin',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'DetectHtml' => array(
      '#type' => 'checkbox',
      '#title' => t('Detect HTML'),
      '#description' => t('If true, the mailing should detect if the recipient has the ability to read HTML.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'DontAttemptAfterDate' => array(
      '#type' => 'date',
      '#title' => t('Don\'t Attempt After'),
      '#description' => t('The "kill date" after which this mailing should no longer be delivered.'),
      '#default_value' => NULL,
      '#api' => array('10'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 10,
        'unsigned' => TRUE,
      ),
      '#defaultable' => FALSE,
    ),
    'EnableRecency' => array(
      '#type' => 'checkbox',
      '#title' => t('Enable Recency'),
      '#description' => t('If true, recency checking should be done for this mailing.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => 80,
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'From' => array(
      '#type' => 'textfield',
      '#title' => t('From'),
      '#description' => t('Format: <strong>name@example.com</strong> or <strong>"John Doe" &lt;johndoe@example.com&gt;</strong>'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => 4,
      '#group' => 'basic',
      '#schema' => array(
        'type' => 'text',
      ),
      '#defaultable' => FALSE,
      '#overrides' => array(
        'defaults_form' => array('#description' => t('The default "From" header is defined in the content.<br />Select an \'Edit\' permission to alter the value per mailing.')),
      ),
      '#permission' => array('hide' => FALSE, 'write' => FALSE),
    ),
    'HtmlMessage' => array(
      '#type' => 'textarea',
      '#title' => t('The HTML portion of the mailing.'),
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'basic',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'HtmlSectionEncoding' => array(
      '#type' => 'textfield',
      '#title' => t('HTML Section Encoding'),
      '#description' => t('The HTML message encoding.'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 1,
      '#api' => array('10', '11', '12'),
      '#group' => 'advanced',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'IsHtmlSectionEncoded' => array(
      '#type' => 'checkbox',
      '#title' => t('Is HTML Section Encoded?'),
      '#description' => t('If true, the HTML portion of the mailing has been encoded.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'advanced',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'IsTextSectionEncoded' => array(
      '#type' => 'checkbox',
      '#title' => t('Is Text Section Encoded?'),
      '#description' => t('If true, the text portion of the mailing has been encoded.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'dvanced',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'ListName' => array(
      '#type' => 'item',
      '#title' => t('Lyris List Name'),
      '#default_value' => NULL,
      '#default_description' => t('The list this mailing is posted to.'),
      '#schema' => array(
        'type' => 'varchar',
        'length' => '255',
        'not null' => TRUE,
      ),
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => -98,
      '#defaultable' => FALSE,
    ),
    'RecencyNumberOfMailings' => array(
      '#type' => 'textfield',
      '#title' => t('Recency Limit'),
      '#description' => t('If enabled, the number of mailings that should trigger recency limits.'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 1,
      '#api' => array('10', '11', '12'),
      '#group' => 'admin',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'RecencyWhich' => array(
      '#type' => 'select',
      '#title' => t('Recency Operator'),
      '#description' => t('When checking for recency, should the number of mailings be more than, equal to or less than the number in Recency Limit.'),
      '#options' => lyris_enum('RecencyOperatorEnum'),
      '#default_value' => 'm',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'varchar',
        'length' => 1,
      ),
    ),
    'ReplyTo' => array(
      '#type' => 'textfield',
      '#title' => t('The "Reply-To:" Header'),
      '#description' => t('Format: <strong>name@example.com</strong> or <strong>"John Doe" &lt;johndoe@example.com&gt;</strong>'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'basic',
      '#weight' => 6,
      '#schema' => array(
        'type' => 'text',
      ),
      '#overrides' => array(
        'entity_form' => array('#description' => t('The Reply-To field must be set in the list settings.')),
        'defaults_form' => array('#description' => t('The default \'Reply-To\' header is set in each list.')),
      ),
      '#permission' => array('hide' => FALSE, 'write' => FALSE),
      '#defaultable' => FALSE,
    ),
    'ResendAfterDays' => array(
      '#type' => 'textfield',
      '#title' => t('Resend Mailing After'),
      '#description' => t('If set, means that when the message is approved, it should be resubmitted for automatic approval after so many days.'),
      '#field_suffix' => t('days'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'admin',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'SampleSize' => array(
      '#type' => 'textfield',
      '#title' => t('Max Recipients'),
      '#description' => t('The maximum number of recipients to receive this mailing. If not set, there is no maximum.'),
      '#size' => 10,
      '#maxlength' => 8,
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'admin',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
    ),
    'ScheduledMailingDate' => array(
      '#type' => 'date',
      '#title' => t('Mailing Date'),
      '#description' => t('The date and time the mailing is scheduled to be sent.'),
      '#default_value' => NULL,
      '#api' => array('10'),
      '#group' => 'advanced',
      '#schema' => array(
        'type' => 'int',
        'length' => 10,
        'unsigned' => TRUE,
      ),
      '#defaultable' => FALSE,
    ),
    'Subject' => array(
      '#type' => 'textfield',
      '#title' => t('Subject'),
      '#description' => t('The "Subject:" header.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'basic',
      '#required' => TRUE,
      '#schema' => array(
        'type' => 'text',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
      ),
    ),
    'TextMessage' => array(
      '#type' => 'textarea',
      '#title' => t('The text portion of the mailing.'),
      '#default_value' => NULL,
      '#api' => array('10', '11', '12'),
      '#group' => 'basic',
      '#schema' => array(
        'type' => 'text',
        'size' => 'big',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'TextSectionEncoding' => array(
      '#type' => 'textfield',
      '#title' => t('Text Section Encoding'),
      '#description' => t('The text message encoding.'),
      '#size' => 10,
      '#maxlength' => 4,
      '#default_value' => 1,
      '#api' => array('10', '11', '12'),
      '#group' => 'advanced',
      '#element_validate' => array('_lyris_element_validate_integer'),
      '#schema' => array(
        'type' => 'int',
      ),
      '#filter' => array(
        'defaults_form' => FALSE,
        'entity_form' => FALSE,
      ),
    ),
    'Title' => array(
      '#type' => 'textfield',
      '#title' => t('Mailing Title'),
      '#description' => t('The title of the mailing.  Must be unique amongst mailing titles.'),
      '#default_value' => NULL,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#weight' => -10,
      '#required' => TRUE,
      '#schema' => array(
        'type' => 'text',
      ),
      '#defaultable' => FALSE,
      '#overrides' => array(
        'defaults_form' => array('#description' => t('Lyris will use the content title to create a unique mailing title.<br />Select an \'Edit\' permission to customize the title per mailing.')),
      ),
      '#permission' => array('hide' => FALSE),
    ),
    'To' => array(
      '#type' => 'textfield',
      '#title' => t('To'),
      '#description' => t('This is the address that will show up in the \'To\' header for all recipients. IT DOES NOT AFFECT WHO RECEIVES THE MAILING!') . '<br />' .
                        t('To show each recipient\'s address in the \'To\' header as it was delivered directly to just them, use the token "[lyris_mailing:email]".'),
      '#default_value' => '[lyris_mailing:email]',
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'basic',
      '#weight' => 0,
      '#schema' => array(
        'type' => 'text',
      ),
      '#defaultable' => FALSE,
      '#permission' => array('hide' => FALSE, 'write' => FALSE),
    ),
    'TrackOpens' => array(
      '#type' => 'checkbox',
      '#title' => t('Track Opens'),
      '#description' => t('If true, this mailing should detect if recipients open it.'),
      '#default_value' => 1,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'advanced',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
    'RewriteDateWhenSent' => array(
      '#type' => 'checkbox',
      '#title' => t('Rewrite Send Date'),
      '#description' => t('If true, the mailing should have its "Date:" header rewritten to be the time it was actually sent, removing the original "Date:" header.'),
      '#default_value' => 0,
      '#api' => array('1.5.2a', '10', '11', '12'),
      '#group' => 'admin',
      '#schema' => array(
        'type' => 'int',
        'length' => 1,
        'unsigned' => TRUE,
      ),
    ),
  );

  return $fields;
}

/**
 * Lyris Enumerations
 */
function lyris_enum($type) {
  $enums = array(
    'ConfirmUnsubEnum' => array(
      0 => t('Confirm on Questionable Requests'),
      1 => t('Always Confirm'),
      2 => t('Never Confirm')
    ),
    'DeliveryReportEnum' => array(
      0 => t('No Reports'),
      1 => t('After 1 Hour'),
      2 => t('After 4 Hours'),
      4 => t('After 12 Hours'),
      8 => t('After 24 Hours'),
      16 => t('After 48 Hours'),
    ),
    'DocTypeEnum' => array(
      'BILLING' => t('Billing Invoice Data'),
      'CONTENTv2' => t('Mailing List Content'),
      'MESSAGE' => t('Internal Message'),
    ),
    'EnableScriptingEnum' => array(
      0 => t('Admins Only'),
      1 => t('Any List Member'),
      2 => t('Scripting Disabled'),
    ),
    'LoggingLevelEnum' => array(
      'N' => t('No Logs'),
      'M' => t('Errors w/o SMTP Info'),
      'E' => t('Errors with SMTP Info'),
      'F' => t('Errors and Successes'),
    ),
    'MailSectionEncodingEnum' => array(
      '7bit' => t('7 Bit'),
      '8bit' => t('8 Bit'),
      'quoted-printable' => t('Quoted Printable'),
      'base64' => t('Base 64'),
    ),
    'MemberListSecurityEnum' => array(
      0 => t('Admins Only'),
      1 => t('List Members'),
      2 => t('Anyone'),
    ),
    'MergeCapOverrideEnum' => array(
      0 => t('No Scripting'),
      1 => t('Safe Scripting'),
      2 => t('Full Scripting'),
      3 => t('Use Server Settings'),
    ),
    'ModeratedEnum' => array(
      'no' => t('No Moderation'),
      'all' => t('Moderate All Messages'),
      'number' => t('Use List Member Approval Number'),
    ),
    'MRIVisibilityEnum' => array(
      'V' => t('Visible'),
      'H' => t('Hidden but Accessible'),
      'I' => t('Invisible and Inaccessible'),
    ),
    'NameRequiredEnum' => array(
      0 => t('Optional'),
      1 => t('Do Not Ask'),
      2 => t('Required'),
    ),
    'NewSubscriberSecurityEnum' => array(
      'open' => t('Anyone May Join'),
      'private' => t('Admin Approval Required'),
      'closed' => t('Only Admin May Subscribe Users'),
      'password' => t('Password Required'),
    ),
    'PostPasswordEnum' => array(
      0 => t('Required'),
      1 => t('Not Required')
    ),
    'RecencyOperatorEnum' => array(
      'm' => t('Greater Than'),
      'f' => t('Less Than'),
      'e' => t('Equal To'),
    ),
    'ScriptingLevelEnum' => array(
      0 => t('No Scripting'),
      1 => t('Safe Scripting'),
      2 => t('Full Scripting'),
    ),
    'SubscriptionReportEnum' => array(
      'none' => t('Do not email sub/unsub delivery reports to list admins'),
      'monthly' => t('Monthly: send a standard monthly report on the 1st of the month'),
      'monthly-email' => t('Monthly: send a detailed monthly report on the 1st of the month'),
      'monthly-nochart' => t('Monthly: send a short monthly report on the 1st of the month'),
      'daily' => t('Daily: send a standard report every day'),
      'daily-email' => t('Daily: send a detailed report every day'),
      'daily-nochart' => t('Daily: send a short report every day'),
      'monday' => t('Weekly: every Monday send a standard weekly report'),
      'monday-email' => t('Weekly: every Monday send a detailed weekly report'),
      'monday-nochart' => t('Weekly: every Monday send a short weekly report'),
      'tuesday' => t('Weekly: every Tuesday send a standard weekly report'),
      'tuesday-email' => t('Weekly: every Tuesday send a detailed weekly report'),
      'tuesday-nochart' => t('Weekly: every Tuesday send a short weekly report'),
      'wednesday' => t('Weekly: every Wednesday send a standard weekly report'),
      'wednesday-email' => t('Weekly: every Wednesday send a detailed weekly report'),
      'wednesday-nochart' => t('Weekly: every Wednesday send a short weekly report'),
      'thursday' => t('Weekly: every Thursday send a standard weekly report'),
      'thursday-email' => t('Weekly: every Thursday send a detailed weekly report'),
      'thursday-nochart' => t('Weekly: every Thursday send a short weekly report'),
      'friday' => t('Weekly: every Friday send a standard weekly report'),
      'friday-email' => t('Weekly: every Friday send a detailed weekly report'),
      'friday-nochart' => t('Weekly: every Friday send a short weekly report'),
      'saturday' => t('Weekly: every Saturday send a standard weekly report'),
      'saturday-email' => t('Weekly: every Saturday send a detailed weekly report'),
      'saturday-nochart' => t('Weekly: every Saturday send a short weekly report'),
      'sunday' => t('Weekly: every Sunday send a standard weekly report'),
      'sunday-email' => t('Weekly: every Sunday send a detailed weekly report'),
      'sunday-nochart' => t('Weekly: every Sunday send a short weekly report'),
    ),
  );

  return $enums[$type];
}
